QrListDecoder class

Constructors

QrListDecoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeScannedData(String rawData) Map<String, dynamic>?
Takes a raw string from a QR scanner and returns a structured Map. Returns null if the data is invalid or not from this package.